# Keyboard Controls

## Global Keys

| Key | Action |
|-----|--------|
| F1 | Help (when available) |
| F3 | Cancel / Exit |
| Ctrl+C | Interrupt |

## Form Navigation

| Key | Action |
|-----|--------|
| Tab | Next field |
| Shift+Tab | Previous field |
| Enter | Submit form |
| F4 | Prompt (show selection list, when available) |

## Field Editing

| Key | Action |
|-----|--------|
| Left/Right | Move cursor within field |
| Home | Jump to start of field |
| End | Jump to end of field |
| Delete | Delete character at cursor |
| Backspace | Delete character before cursor |
| Insert | Toggle insert/overwrite mode |
| Ctrl+E | Erase to end of field |

## Menu Selection

| Key | Action |
|-----|--------|
| 1-9, A-Z | Select menu item |
| X | Exit menu |
| F3 | Exit menu |

## Table / List Navigation

| Key | Action |
|-----|--------|
| F7 | Page backward |
| F8 | Page forward |
| Page Up | Page backward |
| Page Down | Page forward |

## Work-with List

| Key | Action |
|-----|--------|
| Enter | Process action codes |
| F3 | Exit |
| F6 | Add new record (when available) |
| F7 | Page backward |
| F8 | Page forward |

Type action codes in the Opt column:

- `2` = Change
- `4` = Delete
- `5` = Display
- (Application-defined codes)

## Selection List

| Key | Action |
|-----|--------|
| S | Select item (type in Opt column) |
| Enter | Confirm selection |
| F3 | Cancel |
| F6 | Add new item (when available) |
| F7 | Page backward |
| F8 | Page forward |

## Tabular Entry

| Key | Action |
|-----|--------|
| Tab | Next editable cell |
| Shift+Tab | Previous editable cell |
| Enter | Submit all values |
| F3 | Cancel |
| F7 | Page backward |
| F8 | Page forward |
